@@ -52,6 +52,7 @@ from teslajsonpy.homeassistant.sentry_mode import SentryModeSwitch
 from teslajsonpy.homeassistant.trunk import FrunkLock, TrunkLock
 from teslajsonpy.homeassistant.heated_steering_wheel import HeatedSteeringWheelSwitch
 from teslajsonpy.homeassistant.power import PowerSensor
+from teslajsonpy.homeassistant.alerts import Horn, FlashLights
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -668,6 +669,8 @@ class Controller:
         self.__components.append(FrunkLock(car, self))
         self.__components.append(UpdateSensor(car, self))
         self.__components.append(HeatedSteeringWheelSwitch(car, self))
+        self.__components.append(Horn(car, self))
+        self.__components.append(FlashLights(car, self))
         for seat in ["left", "right", "rear_left", "rear_center", "rear_right"]:
             try:
                 self.__components.append(HeatedSeatSelect(car, self, seat))
