@@ -6,11 +6,10 @@ https://github.com/zabuldon/teslajsonpy
 """
 import logging
 from typing import Dict, Text
+from teslajsonpy.const import TESLA_DEFAULT_ENERGY_SITE_NAME
 
 _LOGGER = logging.getLogger(__name__)
 
-TESLA_DEFAULT_ENEREGY_SITE_NAME = "My Home"
-
 
 class EnergySiteDevice:
     """Home-assistant class of Tesla Energy Sites.
@@ -36,7 +35,7 @@ class EnergySiteDevice:
         """
         self._id: int = data["id"]
         self._energy_site_id: int = data["energy_site_id"]
-        self._site_name: Text = data.get("site_name", TESLA_DEFAULT_ENEREGY_SITE_NAME)
+        self._site_name: Text = data.get("site_name", TESLA_DEFAULT_ENERGY_SITE_NAME)
         self._solar_type: Text = data["solar_type"]
         self._controller = controller
         self.should_poll: bool = True
